==> medlogics-common-classes-1.1-20251009.090245-426.jar: com/floreantpos/report/DiscountReportDataModel.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.report;

import java.util.ArrayList;
import java.util.List;

import com.floreantpos.model.util.DateUtil;
import com.floreantpos.swing.ListTableModel;

public class DiscountReportDataModel extends ListTableModel {

	public DiscountReportDataModel() {
		setColumnNames(new String[] { "itemName", "ticketId", "date", "discount", "totalWithDiscount", "discountName", //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$ //$NON-NLS-6$
				"referrerName", "referrerId", "subTotal", "givenByUserName" }); //$NON-NLS-1$ //$NON-NLS-2$
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		DiscountData data = (DiscountData) rows.get(rowIndex);

		switch (columnIndex) {
			case 0:
				return data.getItemName();

			case 1:
				return data.getTicketId();

			case 2:
				return DateUtil.formatReportDateWithBrowserTimeOffset(data.getDate());

			case 3:
				return data.getDiscount();

			case 4:
				return data.getTotalWithDiscount();

			case 5:
				return data.getDiscountName();

			case 6:
				return data.getReferrerName();

			case 7:
				return data.getReferrerId();

			case 8:
				return data.getSubTotal();

			case 9:
				return data.getDiscountGivenByUserName();
		}
		return null;
	}

	public void addDiscountDataList(List<DiscountData> itemDiscounts) {
		if (itemDiscounts == null || itemDiscounts.isEmpty()) {
			return;
		}
		if (getRows() == null) {
			setRows(new ArrayList<>());
		}
		getRows().addAll(itemDiscounts);
	}

}

==> medlogics-common-classes-1.4.7.jar: com/floreantpos/report/DiscountReportDataModel.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.report;

import java.util.ArrayList;
import java.util.List;

import com.floreantpos.model.util.DateUtil;
import com.floreantpos.swing.ListTableModel;

public class DiscountReportDataModel extends ListTableModel {

	public DiscountReportDataModel() {
		setColumnNames(new String[] { "itemName", "ticketId", "date", "discount", "totalWithDiscount", "discountName", "referrerName", "referrerId" }); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$ //$NON-NLS-6$ //$NON-NLS-7$ //$NON-NLS-8$
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		DiscountData data = (DiscountData) rows.get(rowIndex);

		switch (columnIndex) {
			case 0:
				return data.getItemName();

			case 1:
				return data.getTicketId();

			case 2:
				return DateUtil.formatReportDateWithBrowserTimeOffset(data.getDate());

			case 3:
				return data.getDiscount();

			case 4:
				return data.getTotalWithDiscount();

			case 5:
				return data.getDiscountName();
			case 6:
				return data.getReferrerName();
			case 7:
				return data.getReferrerId();
		}
		return null;
	}

	public void addDiscountDataList(List<DiscountData> itemDiscounts) {
		if (itemDiscounts == null || itemDiscounts.isEmpty()) {
			return;
		}
		if (getRows() == null) {
			setRows(new ArrayList<>());
		}
		getRows().addAll(itemDiscounts);
	}

}
